==> nextcloud-28.0.7.tar.bz2: nextcloud/apps/photos/l10n/eu.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Esteka publikoa",
    "Photos" : "Argazkiak",
    "On This Day" : "Egun honetan",
    "Your memories under your control" : "Zure oroitzapenak zure kontrolpean",
    "All media" : "Fitxategi guztiak",
    "Videos" : "Bideoak",
    "Albums" : "Albumak",
    "Collaborative albums" : "Elkarlaneko albumak",
    "People" : "Jendea",
    "Folders" : "Karpetak",
    "Favorites" : "Gogokoak",
    "On this day" : "Egun honetan",
    "Shared with you" : "Zurekin partekatua",
    "Tags" : "Etiketak",
    "Places" : "Lekuak",
    "Map" : "Mapa",
    "Photos settings" : "Argazkien ezarpenak",
    "Mark selection as favorite" : "Markatu hautatutakoak gogoko gisa",
    "Add selection to favorites" : "Gehitu hautatutakoak gogokoetara",
    "Remove selection from favorites" : "Kendu hautatutakoak gogokoetatik",
    "Name of the album" : "Albumaren izena",
    "Location of the album" : "Albumaren kokapena",
    "Back" : "Atzera",
    "Add collaborators" : "Gehitu kolaboratzaileak",
    "Save" : "Gorde",
    "Create album" : "Sortu albuma",
    "Add to Album" : "Gehitu album batera",
    "Add selection to album {albumName}" : "Gehitu hautapena {albumName} albumera",
    "Shared by" : "Honek partekatua",
    "Create a new album." : "Sortu album berria.",
    "Create new album" : "Sortu album berria",
    "New album" : "Album berria",
    "_%n item_::_%n photos and videos_" : ["%n fitxategi","%n argazki eta bideo"],
    "Add people or groups who can edit your album" : "Gehitu zure albuma editatu dezaketen pertsona edo taldeak",
    "Search people or groups" : "Bilatu erabiltzaile edo taldeak",
    "No recommendations. Start typing." : "Gomendiorik ez. Hasi idazten.",
    "Group" : "Taldea",
    "Remove {collaboratorLabel} from the collaborators list" : "Kendu {collaboratorLabel} kolaboratzaile zerrendatik",
    "Copy the public link" : "Kopiatu esteka publikoa",
    "Public link copied!" : "Esteka publikoa kopiatuta!",
    "Copy public link" : "Kopiatu esteka publikoa",
    "Delete the public link" : "Ezabatu esteka publikoa",
    "Create public link share" : "Sortu partekatze esteka publikoa",
    "Share via public link" : "Partekatu esteka publiko bidez",
    "Failed to fetch collaborators list." : "Ezin izan da kolaboratzaile zerrenda lortu.",
    "Failed to update album." : "Ezin izan da albuma eguneratu.",
    "This collection does not exist" : "Bilduma hau ez da existitzen",
    "An error occurred" : "Errore bat gertatu da",
    "No picture for this day" : "Ez dago argazkirik egun honentzat",
    "Picture taken on this day will show up here." : "Egun honetan hartutako argazkia hemen agertuko da.",
    "More photos from this day" : "Egun honetako argazki gehiago",
    "_%n unassigned photo_::_%n unassigned photos_" : ["Esleitu gabeko argazki %n","%n esleitu gabeko argazki"],
    "Favorite" : "Egin gogoko",
    "Select image {imageName}" : "Hautatu irudia {imageName}",
    "Favorite image, open the full size \"{name}\" image" : "Irudi gogokoa, ireki \"{name}\" irudia neurri handian",
    "Open the full size \"{name}\" image" : "Ireki \"{name}\" neurri handian",
    "Open the \"{name}\" folder" : "Ireki \"{name}\" karpeta",
    "Go back" : "Atzera",
    "Back to {folder}" : "Itzuli {folder}(e)ra",
    "Share this folder" : "Partekatu karpeta hau",
    "Dates" : "Datak",
    "Jump to specific date in list" : "Joan zerrendako data zehatz batera",
    "Jump to {date}" : "Joan {date} datara",
    "Add to {destination}" : "Gehitu hona: {destination}",
    "There are no photos or videos yet!" : "Ez dago argazki edo bideorik oraindik!",
    "_{years} year ago_::_{years} years ago_" : ["orain dela urte {years}","orain dela {years} urte"],
    "Enable squared photos view" : "Gaitu lauki formako argazki ikuspegia",
    "Delete source directory" : "Ezabatu iturburuko direktorioa",
    "All folders" : "Karpeta guztiak",
    "Add a Photos source for the timelines" : "Gehitu argazki iturri bat denbora-lerroetarako",
    "Add folder" : "Gehitu karpeta",
    "Select a source folder for your media" : "Hautatu iturburu karpeta bat zure multimedia fitxategientzat",
    "Home" : "Etxea",
    "Choose default Photos upload and Albums location" : "Aukeratu argazkien igoera eta albumen kokaleku lehenetsia",
    "Choose a different folder" : "Aukeratu beste karpeta bat",
    "Select the default upload location for your media" : "Hautatu lehenetsitako kokalekua zure multimedia fitxategiak igotzeko",
    "View" : "Ikusi",
    "Media folders" : "Multimedia karpetak",
    "Choose the folders from where photos and videos are shown." : "Aukeratu zein karpetatatik erakutsiko diren argazki eta bideoak.",
    "Upload folder" : "Igo karpeta",
    "Choose the folder where photos and albums are uploaded to." : "Aukeratu zein karpetatara igoko diren argazki eta albumak.",
    "_%n photo_::_%n photos_" : ["argazki %n","%n argazki"],
    "Unselect all" : "Desautatu dena",
    "Manage collaborators for this album" : "Kudeatu album honen kolaboratzaileak",
    "Open actions menu" : "Ireki ekintzen menua",
    "Edit album details" : "Editatu albumaren xehetasunak",
    "Download all files in album" : "Deskargatu albumeko fitxategi guztiak",
    "Delete album" : "Ezabatu albuma",
    "Download selected files" : "Deskargatu hautatutakoak",
    "Remove selection from album" : "Kendu hautatutakoak albumetik",
    "This album does not have any photos or videos yet!" : "Album honek ez du argazki edo bideorik oraindik!",
    "Add photos to this album" : "Gehitu argazkiak album honetara ",
    "Add photos to {albumName}" : "Gehitu argazkiak {albumName}(e)ra",
    "Manage collaborators" : "Kudeatu kolaboratzaileak",
    "Save collaborators for this album." : "Gorde album honen kolaboratzaileak.",
    "Cover photo for album {albumName}" : "{albumName} albumaren azaleko argazkia",
    "There is no album yet!" : "Ez dago albumik oraindik!",
    "This person could not be found" : "Ezin izan da pertsona hori aurkitu",
    "Rename person" : "Berridatzi pertsonaren izena",
    "Merge with different person" : "Bateratu beste pertsona batekin",
    "Download selected photos" : "Deskargatu hautatutako argazkiak",
    "Remove from favorites" : "Kendu gogokoetatik",
    "Remove person" : "Kendu pertsona",
    "Name of this person" : "Pertsona honen izena",
    "Save." : "Gorde.",
    "Merge person" : "Bateratu pertsona",
    "Move to different person" : "Mugitu beste pertsona batera",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mugitu argazkia beste pertsona batera","Mugitu argazkiak beste pertsona batera"],
    "_Remove photo from person_::_Remove photos from person_" : ["Kendu argazkia pertsonatik","Kendu argazkiak pertsonatik"],
    "This might take some time depending on the size of your photo library." : "Honek luze jo dezake, zure argazki liburutegiaren tamainaren arabera.",
    "Recognized people will show up here" : "Ezagutu diren pertsonak hemen agertuko dira",
    "This folder does not exist" : "Karpeta hau ez da existitzen",
    "Loading folders …" : "Karpetak kargatzen ...",
    "No photos in here" : "Argazkirik ez hemen",
    "Taken on {date} at {time}" : "{date} egunean {time} orduan ateratakoa",
    "This place does not have any photos or videos yet!" : "Toki honek ez du argazki edo bideorik oraindik!",
    "Add photos to this place" : "Gehitu argazkiak leku honetara",
    "Cover photo for place {placeName}" : "{placeName} tokiaren azaleko argazkia",
    "There is no place yet!" : "Oraindik ez dago lekurik!",
    "Cover photo for shared album {albumName}." : "{albumName} album partekatuko azaleko argazkia",
    "Back to tags overview" : "Itzuli etiketen ikuspegira",
    "No photos with this tag yet" : "Ez dago etiketa hau duen argazkirik oraindik",
    "No tags yet" : "Etitketarik ez oraindik",
    "Photos with tags will show up here" : "Etiketadun argazkiak hemen erakutsiko dira",
    "Popular tags" : "Etiketa ohikoak",
    "One of the source folders does not exists" : "Iturburu-karpeta bat ez da existitzen",
    "Add" : "Gehitu",
    "Add to album" : "Gehitu albumera",
    "Delete selection" : "Ezabatu hautatutakoak",
    "No photos or videos in here" : "Ez dago argazki edo bideorik hemen",
    "Unassigned faces" : "Esleitu gabeko aurpegiak",
    "_%n photos_::_%n photos_" : ["argazki %n","%n argazki"],
    "Failed to fetch collection." : "Ezin izan da bilduma eskuratu.",
    "Failed to fetch collections list." : "Ezin izan da bildumen zerrenda eskuratu.",
    "Failed to fetch faces list." : "Ezin izan da aurpegien zerrenda eskuratu.",
    "All your media" : "Zure multimedia guztia",
    "Album {title}" : "{title} albuma",
    "Shared Albums" : "Partekatutako albumak",
    "Shared album {title}" : "{title} partekatutako albuma",
    "Public album {title}" : "{title} album publikoa",
    "Tagged photos" : "Etiketaturiko argazkiak",
    "Tagged photo {title}" : "{title} etiketaturiko argazkia",
    "{title}'s face" : "{title}(r)en aurpegia",
    "{startDate} to {endDate}" : "{startDate} - {endDate}",
    "Details" : "Xehetasunak",
    "Failed to rename {oldName} to {faceName}." : "Ezin izan da {oldName} berrizendatu {faceName} gisa.",
    "Failed to delete {faceName}." : "Ezin izan da  {faceName} ezabatu.",
    "Failed to delete {fileId}." : "{fileId} ezabatzeak huts egin du.",
    "Failed to delete {fileName}." : "{fileName} ezabatzeak huts egin du.",
    "Failed to set favorite state for {fileId}." : "Ezin izan da ezarri gogoko egoera {fileId}(r)entzat.",
    "Failed to set favorite state for {fileName}." : "Ezin izan da ezarri gogoko egoera {fileName}(r)entzat.",
    "Could not load photos folder" : "Ezin izan da argazkien karpeta kargatu",
    "Go back to the previous view." : "Itzuli aurreko ikuspegira.",
    "Go to the add collaborators view." : "Joan kolaboratzaileak gehitzeko ikuspegira.",
    "Create the album." : "Sortu albuma.",
    "Back to the new album form." : "Itzuli album berrien formulariora",
    "_Share with %n user_::_Share with %n users_" : ["Partekatu %n erabiltzailearekin","Partekatu %n erabiltzaileekin"],
    "Search for collaborators" : "Bilatu kolaboratzaileak",
    "Add {collaboratorLabel} to the collaborators list" : "Gehitu {collaboratorLabel} kolaboratzaile zerrendara",
    "No collaborators available" : "Ez dago kolaboratzailerik eskuragarri",
    "Failed to fetch album." : "Ezin izan da albuma lortu.",
    "The file is in the favorites" : "Fitxategia gogokoetan dago",
    "Open the \"{name}\" sub-directory" : "Ireki \"{name}\" azpi-direktorioa",
    "Default Photos upload and Albums location" : "Argazkien karga eta albumen kokaleku lehenetsia",
    "Select the default location for your media" : "Hautatu zure multimediaren kokaleku lehenetsia",
    "Invalid location selected" : "Kokaleku baliogabea hautatu da",
    "Photos directory" : "Argazkien direktorioa",
    "Add photos to the album" : "Gehitu argazkiak albumera",
    "Failed to fetch albums list." : "Ezin izan da album zerrenda eskuratu.",
    "Shared albums" : "Partekaturiko albumak",
    "Create a new album" : "Sortu album berri bat",
    "Add selection to an album" : "Gehitu hautatutakoak album batera",
    "Failed to create {albumName}." : "Ezin izan da {albumName} sortu.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Ezin izan da {currentAlbumName} berrizendatu {newAlbumName} gisa."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.17.tar.bz2: nextcloud/apps/photos/l10n/eu.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Esteka publikoa",
    "Photos" : "Argazkiak",
    "On This Day" : "Egun honetan",
    "Your memories under your control" : "Zure oroitzapenak zure kontrolpean",
    "All media" : "Fitxategi guztiak",
    "Videos" : "Bideoak",
    "Albums" : "Albumak",
    "Collaborative albums" : "Elkarlaneko albumak",
    "People" : "Jendea",
    "Folders" : "Karpetak",
    "Favorites" : "Gogokoak",
    "On this day" : "Egun honetan",
    "Shared with you" : "Zurekin partekatua",
    "Tags" : "Etiketak",
    "Places" : "Lekuak",
    "Map" : "Mapa",
    "Photos settings" : "Argazkien ezarpenak",
    "Mark selection as favorite" : "Markatu hautatutakoak gogoko gisa",
    "Add selection to favorites" : "Gehitu hautatutakoak gogokoetara",
    "Remove selection from favorites" : "Kendu hautatutakoak gogokoetatik",
    "This name is already in use." : "Izen hau dagoeneko erabiltzen ari da.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" ez da onartzen fitxategi-izen baten barruan.",
    "Invalid filename." : "Fitxategi-izen baliogabea.",
    "Name of the album" : "Albumaren izena",
    "Location of the album" : "Albumaren kokapena",
    "Back" : "Atzera",
    "Add collaborators" : "Gehitu kolaboratzaileak",
    "Save" : "Gorde",
    "Create album" : "Sortu albuma",
    "Add to Album" : "Gehitu album batera",
    "Add selection to album {albumName}" : "Gehitu hautapena {albumName} albumera",
    "Shared by" : "Honek partekatua",
    "Create a new album." : "Sortu album berria.",
    "Create new album" : "Sortu album berria",
    "New album" : "Album berria",
    "_%n item_::_%n photos and videos_" : ["%n fitxategi","%n argazki eta bideo"],
    "Failed to fetch collaborators list." : "Ezin izan da kolaboratzaile zerrenda lortu.",
    "Failed to update album." : "Ezin izan da albuma eguneratu.",
    "Add people or groups who can edit your album" : "Gehitu zure albuma editatu dezaketen pertsona edo taldeak",
    "Search people or groups" : "Bilatu erabiltzaile edo taldeak",
    "No recommendations. Start typing." : "Gomendiorik ez. Hasi idazten.",
    "Copy the public link" : "Kopiatu esteka publikoa",
    "Public link copied!" : "Esteka publikoa kopiatuta!",
    "Copy public link" : "Kopiatu esteka publikoa",
    "Delete the public link" : "Ezabatu esteka publikoa",
    "Create public link share" : "Sortu partekatze esteka publikoa",
    "Share via public link" : "Partekatu esteka publiko bidez",
    "This collection does not exist" : "Bilduma hau ez da existitzen",
    "An error occurred" : "Errore bat gertatu da",
    "No picture for this day" : "Ez dago argazkirik egun honentzat",
    "Picture taken on this day will show up here." : "Egun honetan hartutako argazkia hemen agertuko da.",
    "More photos from this day" : "Egun honetako argazki gehiago",
    "_%n photos_::_%n photos_" : ["argazki %n","%n argazki"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["Esleitu gabeko argazki %n","%n esleitu gabeko argazki"],
    "Favorite" : "Egin gogoko",
    "Favorite image, open the full size \"{name}\" image" : "Irudi gogokoa, ireki \"{name}\" irudia neurri handian",
    "Open the full size \"{name}\" image" : "Ireki \"{name}\" neurri handian",
    "Select image {imageName}" : "Hautatu irudia {imageName}",
    "Open the \"{name}\" folder" : "Ireki \"{name}\" karpeta",
    "Go back" : "Atzera",
    "Select a custom date range" : "Hautatu data tarte pertsonalizatu bat",
    "Select a date range" : "Hautatu data tarte bat",
    "Date range" : "Data tartea",
    "Select filters" : "Hautatu iragazkiak",
    "Dates" : "Datak",
    "Jump to specific date in list" : "Joan zerrendako data zehatz batera",
    "Jump to {date}" : "Joan {date} datara",
    "Add to {destination}" : "Gehitu hona: {destination}",
    "The destination folder is owned by {owner}" : " Helburu karpetaren jabea {owner} da",
    "There are no photos or videos yet!" : "Ez dago argazki edo bideorik oraindik!",
    "_{years} year ago_::_{years} years ago_" : ["orain dela urte {years}","orain dela {years} urte"],
    "Enable squared photos view" : "Gaitu lauki formako argazki ikuspegia",
    "Delete source directory" : "Ezabatu iturburuko direktorioa",
    "Pick folder" : "Aukeratu karpeta",
    "Select a source folder for your media" : "Hautatu iturburu karpeta bat zure multimedia fitxategientzat",
    "All folders" : "Karpeta guztiak",
    "Add a Photos source for the timelines" : "Gehitu argazki iturri bat denbora-lerroetarako",
    "Add folder" : "Gehitu karpeta",
    "Select the default upload location for your media" : "Hautatu lehenetsitako kokalekua zure multimedia fitxategiak igotzeko",
    "Home" : "Etxea",
    "Choose default Photos upload and Albums location" : "Aukeratu argazkien igoera eta albumen kokaleku lehenetsia",
    "Choose a different folder" : "Aukeratu beste karpeta bat",
    "View" : "Ikusi",
    "Media folders" : "Multimedia karpetak",
    "Choose the folders from where photos and videos are shown." : "Aukeratu zein karpetatatik erakutsiko diren argazki eta bideoak.",
    "Upload folder" : "Igo karpeta",
    "Choose the folder where photos and albums are uploaded to." : "Aukeratu zein karpetatara igoko diren argazki eta albumak.",
    "_%n photo_::_%n photos_" : ["argazki %n","%n argazki"],
    "Unselect all" : "Desautatu dena",
    "Add photos to this album" : "Gehitu argazkiak album honetara ",
    "Manage collaborators for this album" : "Kudeatu album honen kolaboratzaileak",
    "Open actions menu" : "Ireki ekintzen menua",
    "Edit album details" : "Editatu albumaren xehetasunak",
    "Download all files in album" : "Deskargatu albumeko fitxategi guztiak",
    "Delete album" : "Ezabatu albuma",
    "Download selected files" : "Deskargatu hautatutakoak",
    "Remove selection from album" : "Kendu hautatutakoak albumetik",
    "This album does not have any photos or videos yet!" : "Album honek ez du argazki edo bideorik oraindik!",
    "Add photos to {albumName}" : "Gehitu argazkiak {albumName}(e)ra",
    "Manage collaborators" : "Kudeatu kolaboratzaileak",
    "Save collaborators for this album." : "Gorde album honen kolaboratzaileak.",
    "Cover photo for album {albumName}" : "{albumName} albumaren azaleko argazkia",
    "There is no album yet!" : "Ez dago albumik oraindik!",
    "This person could not be found" : "Ezin izan da pertsona hori aurkitu",
    "Rename person" : "Berridatzi pertsonaren izena",
    "Merge with different person" : "Bateratu beste pertsona batekin",
    "Download selected photos" : "Deskargatu hautatutako argazkiak",
    "Remove from favorites" : "Kendu gogokoetatik",
    "Remove person" : "Kendu pertsona",
    "Name of this person" : "Pertsona honen izena",
    "Save." : "Gorde.",
    "Merge person" : "Bateratu pertsona",
    "Move to different person" : "Mugitu beste pertsona batera",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mugitu argazkia beste pertsona batera","Mugitu argazkiak beste pertsona batera"],
    "_Remove photo from person_::_Remove photos from person_" : ["Kendu argazkia pertsonatik","Kendu argazkiak pertsonatik"],
    "This might take some time depending on the size of your photo library." : "Honek luze jo dezake, zure argazki liburutegiaren tamainaren arabera.",
    "Recognized people will show up here" : "Ezagutu diren pertsonak hemen agertuko dira",
    "This folder does not exist" : "Karpeta hau ez da existitzen",
    "Loading folders…" : "Karpetak kargatzen...",
    "No photos in here" : "Argazkirik ez hemen",
    "Taken on {date} at {time}" : "{date} egunean {time} orduan ateratakoa",
    "This place does not have any photos or videos yet!" : "Toki honek ez du argazki edo bideorik oraindik!",
    "Add photos to this place" : "Gehitu argazkiak leku honetara",
    "Cover photo for place {placeName}" : "{placeName} tokiaren azaleko argazkia",
    "There is no place yet!" : "Oraindik ez dago lekurik!",
    "Cover photo for shared album {albumName}" : "Azaleko argazkia partekatutako {albumName} albumerako",
    "Back to tags overview" : "Itzuli etiketen ikuspegira",
    "No photos with this tag yet" : "Ez dago etiketa hau duen argazkirik oraindik",
    "No tags yet" : "Etitketarik ez oraindik",
    "Photos with tags will show up here" : "Etiketadun argazkiak hemen erakutsiko dira",
    "Popular tags" : "Etiketa ohikoak",
    "All tags" : "Etiketa guztiak",
    "Create new album from filters" : "Sortu album berria iragazkitik abiatuta",
    "One of the source folders does not exist" : "Iturburu-karpeta bat ez da existitzen",
    "Add to album" : "Gehitu albumera",
    "Delete selection" : "Ezabatu hautatutakoak",
    "No photos or videos in here" : "Ez dago argazki edo bideorik hemen",
    "Unassigned faces" : "Esleitu gabeko aurpegiak",
    "Failed to fetch collection." : "Ezin izan da bilduma eskuratu.",
    "Failed to fetch collections list." : "Ezin izan da bildumen zerrenda eskuratu.",
    "Failed to fetch faces list." : "Ezin izan da aurpegien zerrenda eskuratu.",
    "Error fetching files" : "Errorea fitxategiak eskuratzean",
    "All your media" : "Zure multimedia guztia",
    "Album {title}" : "{title} albuma",
    "Shared Albums" : "Partekatutako albumak",
    "Shared album {title}" : "{title} partekatutako albuma",
    "Public album {title}" : "{title} album publikoa",
    "Tagged photos" : "Etiketaturiko argazkiak",
    "Tagged photo {title}" : "{title} etiketaturiko argazkia",
    "{title}'s face" : "{title}(r)en aurpegia",
    "Last week" : "Joan den astean",
    "Last Month" : "Azken hilabetea",
    "Custom…" : "Pertsonalizatu...",
    "{startDate} to {endDate}" : "{startDate} - {endDate}",
    "Details" : "Xehetasunak",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "Huts egin du {fileBaseName} {collectionFileName} bildumara gehitzean",
    "Failed to delete {fileBaseName}" : "Huts egin du {fileBaseName} ezabatzean",
    "Failed to create {collectionFileName}" : "Huts egin du {collectionFileName} sortzean",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Huts egin du {currentCollectionFileName} bildumari {newCollectionFileName}izen berria jartzean",
    "Failed to update properties of {collectionFileName} with {properties}" : "Huts egin du{collectionFileName}eguneratzean {properties} propietateak",
    "Failed to delete {collectionFileName}" : "Huts egin du {collectionFileName} ezabatzean",
    "Failed to move {fileBaseName} to person {faceName}" : "Errorea {fileBaseName} {faceName} pertsonarengana mugitzean",
    "Failed to remove {fileBaseName}" : "Huts egin du {fileBaseName} kentzean",
    "Failed to rename {oldName} to {faceName}" : "Huts egin du {oldName} bildumari {faceName}izen berria jartzean",
    "Failed to delete {faceName}" : "Huts egin du {faceName} ezabatzean",
    "Failed to delete {fileId}" : "Huts egin du {fileId} ezabatzean",
    "Failed to delete {fileName}" : "Huts egin du {fileName} ezabatzean",
    "Could not load photos folder" : "Ezin izan da argazkien karpeta kargatu",
    "Group" : "Taldea",
    "Remove {collaboratorLabel} from the collaborators list" : "Kendu {collaboratorLabel} kolaboratzaile zerrendatik",
    "Back to {folder}" : "Itzuli {folder}(e)ra",
    "Share this folder" : "Partekatu karpeta hau",
    "Loading folders …" : "Karpetak kargatzen ...",
    "One of the source folders does not exists" : "Iturburu-karpeta bat ez da existitzen",
    "Add" : "Gehitu"
},
"nplurals=2; plural=(n != 1);");
